# Coordinate transformation between different Frames. 

# This example illustrates the camera and world coordinate systems
# relationship. The position of the camera in the world coordinate
# system is printed from Camera::position(). Symetrically, the
# position of the world origin is given in the camera coordinate
# system by camera()->cameraCoordinatesOf(0,0,0).

# Three sets of lines (red, green, blue) are drawned. They have different starting points, but
# common end points, located on a circle in the XY plane.

# All the red lines start from the camera position, and will hence always be aligned with the
# viewing direction, making them invisible.

# The green lines starting points' positions are determined from the camera coordinate system, using
# <code>camera()->worldCoordinatesOf()</code>. As a result, these points will seem to be fixed on
# the screen, even when the camera is moved

# Finally, the blue lines are classically defined in the world coordinate system, and will move with
# the camera.

# Beautiful Moire pattern can be obtained with a proper rotation.

TEMPLATE = app
TARGET   = frameTransform
CONFIG  *= qt opengl warn_on release thread

HEADERS  = frameTransform.h
SOURCES  = frameTransform.cpp main.cpp


##  Windows Qt 2.3 users should uncomment the next 2 lines and remove
##  ALL the remaining lines. Make sure that the libQGLViewer files
##  are included in your Tools-Options-Directories paths.
#DEFINES *= QT_DLL QT_THREAD_SUPPORT
#LIBS *= QGLViewer.lib


# Unix : same INCLUDE_DIR and LIB_DIR parameters than for the make install 
unix {
  isEmpty( PREFIX ) {
    PREFIX=/usr/local
  }
  isEmpty( LIB_DIR ) {
    LIB_DIR = $$PREFIX/lib
  }
  isEmpty( INCLUDE_DIR ) {
    INCLUDE_DIR = $$PREFIX/include
  }

  INCLUDE_PATH = $$INCLUDE_DIR/QGLViewer

  !exists( $$INCLUDE_PATH/qglviewer.h ) {
    error( Unable to find header files in $$INCLUDE_DIR. Run qmake INCLUDE_DIR=... )
  }
  !exists( $$LIB_DIR/libQGLViewer.so* ) {
    error( Unable to find libQGLViewer.so in $$LIB_DIR. Run qmake LIB_DIR=... )
  }

  # Path correctly detected
  INCLUDEPATH *= $$INCLUDE_PATH
  DEPENDPATH  *= $$INCLUDE_PATH
  unix:  LIBS *= -L$$LIB_DIR -lQGLViewer
  macx:  LIBS *= -lobjc
}


# Windows. Try ../../src. If it fails, rely on the Visual C++ path options
win32 {
  exists( ../../src/*.h ) {
    INCLUDEPATH *= ../../src
    DEPENDPATH  *= ../../src
  }

  exists( ..\..\src\Release\QGLViewer.lib ) {
    LIB_DIR = ..\..\src\Release
  }

  isEmpty( LIB_DIR ) {
    exists( ..\..\src\Debug\QGLViewer.lib ) {
      LIB_DIR = ..\..\src\Debug
    }
  }

  !isEmpty( LIB_DIR ) {
    LIBS *= $$LIB_DIR\QGLViewer.lib
  }

  isEmpty( LIB_DIR ) {
    LIBS *= QGLViewer.lib
  }

  # Various compilation flags
  QMAKE_CXXFLAGS = -TP -G6 -W1 -GR -GX -Zi
  # Optimise for speed, and expand any suitable inlines :
  QMAKE_CXXFLAGS_RELEASE = -O2 -Ob2

  # Use the Qt DLL version
  DEFINES *= QT_DLL QT_THREAD_SUPPORT
}
