# The KeyFrameInterpolator test example.

# KeyFrameInterpolator smoothly interpolate their attached Frame over time on a path defined by
# Frames. The interpolation can be started/stopped/reset, played in loop, played at a different
# speed, etc...

# In this examples, the path is defined by four ManipulatedFrame which all can be moved with the
# mouse. The interpolating path is updated accordingly.

# The path and the interpolating axis are drawn using KeyFrameInterpolator::drawPath().

# By default, the Camera holds 12 KeyFrameInterpolator, binded to the F1-12 keys. Use Alt-Fx to
# define a new keyFrame for path x, and simply press Fx to play/pause the path x. See the <a
# href="../shortcuts.html">shortcuts</a> page for details.

TEMPLATE = app
TARGET   = keyFrames
CONFIG  += qt opengl warn_on release thread

HEADERS  = keyFrames.h
SOURCES  = keyFrames.cpp main.cpp

##  Windows Qt 2.3 users should uncomment the next 2 lines and remove
##  ALL the remaining lines. Make sure that the libQGLViewer files
##  are included in your Tools-Options-Directories paths.
#DEFINES *= QT_DLL QT_THREAD_SUPPORT
#LIBS *= QGLViewer.lib


# Unix : same INCLUDE_DIR and LIB_DIR parameters than for the make install 
unix {
  isEmpty( PREFIX ) {
    PREFIX=/usr/local
  }
  isEmpty( LIB_DIR ) {
    LIB_DIR = $$PREFIX/lib
  }
  isEmpty( INCLUDE_DIR ) {
    INCLUDE_DIR = $$PREFIX/include
  }

  INCLUDE_PATH = $$INCLUDE_DIR/QGLViewer

  !exists( $$INCLUDE_PATH/qglviewer.h ) {
    error( Unable to find header files in $$INCLUDE_DIR. Run qmake INCLUDE_DIR=... )
  }
  !exists( $$LIB_DIR/libQGLViewer.so* ) {
    error( Unable to find libQGLViewer.so in $$LIB_DIR. Run qmake LIB_DIR=... )
  }

  # Path correctly detected
  INCLUDEPATH *= $$INCLUDE_PATH
  DEPENDPATH  *= $$INCLUDE_PATH
  unix:  LIBS *= -L$$LIB_DIR -lQGLViewer
  macx:  LIBS *= -lobjc
}


# Windows. Try ../../src. If it fails, rely on the Visual C++ path options
win32 {
  exists( ../../src/*.h ) {
    INCLUDEPATH *= ../../src
    DEPENDPATH  *= ../../src
  }

  exists( ..\..\src\Release\QGLViewer.lib ) {
    LIB_DIR = ..\..\src\Release
  }

  isEmpty( LIB_DIR ) {
    exists( ..\..\src\Debug\QGLViewer.lib ) {
      LIB_DIR = ..\..\src\Debug
    }
  }

  !isEmpty( LIB_DIR ) {
    LIBS *= $$LIB_DIR\QGLViewer.lib
  }

  isEmpty( LIB_DIR ) {
    LIBS *= QGLViewer.lib
  }

  # Various compilation flags
  QMAKE_CXXFLAGS = -TP -G6 -W1 -GR -GX -Zi
  # Optimise for speed, and expand any suitable inlines :
  QMAKE_CXXFLAGS_RELEASE = -O2 -Ob2

  # Use the Qt DLL version
  DEFINES *= QT_DLL QT_THREAD_SUPPORT
}
