# A more complex exemple that combines manipulatedFrames, selection and constraints.

# This exemple illustrates different functions of the viewer. It displays a famous luxo lamp
# (Pixar) that can be interactively manipulated with the mouse. It illustrates the use of several
# ManipulatedFrames in the same scene.

# Shift click on any part of the lamp to select it, and then move it with the mouse. To move the
# camera select the background or press the Control key (default modifier keys are switched).

# A simpler object selection example is given in <a href="select.html"><code>select</code></a>.<br/>
# A simpler frame displacement example is given in <a href="manipulatedFrame.html"><code>manipulatedFrame</code></a>.<br/>
# A simpler constrained frame example is given in <a href="constrainedFrame.html"><code>constrainedFrame</code></a>.<br/>

TEMPLATE = app
TARGET   = luxo
CONFIG  += qt opengl warn_on release thread

HEADERS  = luxo.h
SOURCES  = luxo.cpp main.cpp

##  Windows Qt 2.3 users should uncomment the next 2 lines and remove
##  ALL the remaining lines. Make sure that the libQGLViewer files
##  are included in your Tools-Options-Directories paths.
#DEFINES *= QT_DLL QT_THREAD_SUPPORT
#LIBS *= QGLViewer.lib


# Unix : same INCLUDE_DIR and LIB_DIR parameters than for the make install 
unix {
  isEmpty( PREFIX ) {
    PREFIX=/usr/local
  }
  isEmpty( LIB_DIR ) {
    LIB_DIR = $$PREFIX/lib
  }
  isEmpty( INCLUDE_DIR ) {
    INCLUDE_DIR = $$PREFIX/include
  }

  INCLUDE_PATH = $$INCLUDE_DIR/QGLViewer

  !exists( $$INCLUDE_PATH/qglviewer.h ) {
    error( Unable to find header files in $$INCLUDE_DIR. Run qmake INCLUDE_DIR=... )
  }
  !exists( $$LIB_DIR/libQGLViewer.so* ) {
    error( Unable to find libQGLViewer.so in $$LIB_DIR. Run qmake LIB_DIR=... )
  }

  # Path correctly detected
  INCLUDEPATH *= $$INCLUDE_PATH
  DEPENDPATH  *= $$INCLUDE_PATH
  unix:  LIBS *= -L$$LIB_DIR -lQGLViewer
  macx:  LIBS *= -lobjc
}


# Windows. Try ../../src. If it fails, rely on the Visual C++ path options
win32 {
  exists( ../../src/*.h ) {
    INCLUDEPATH *= ../../src
    DEPENDPATH  *= ../../src
  }

  exists( ..\..\src\Release\QGLViewer.lib ) {
    LIB_DIR = ..\..\src\Release
  }

  isEmpty( LIB_DIR ) {
    exists( ..\..\src\Debug\QGLViewer.lib ) {
      LIB_DIR = ..\..\src\Debug
    }
  }

  !isEmpty( LIB_DIR ) {
    LIBS *= $$LIB_DIR\QGLViewer.lib
  }

  isEmpty( LIB_DIR ) {
    LIBS *= QGLViewer.lib
  }

  # Various compilation flags
  QMAKE_CXXFLAGS = -TP -G6 -W1 -GR -GX -Zi
  # Optimise for speed, and expand any suitable inlines :
  QMAKE_CXXFLAGS_RELEASE = -O2 -Ob2

  # Use the Qt DLL version
  DEFINES *= QT_DLL QT_THREAD_SUPPORT
}
